@@ -1,11 +1,9 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 @Author         : yanyongyu
 @Date           : 2022-10-15 08:08:41
 @LastEditors    : yanyongyu
-@LastEditTime   : 2022-10-15 12:00:21
-@Description    : None
+@LastEditTime   : 2023-03-30 18:24:49
+@Description    : Template rendering helpers
 @GitHub         : https://github.com/yanyongyu
 """
 __author__ = "yanyongyu"
